#!/bin/sh
#
# Copyright (C) 2019  Patrick McDermott
#
# This file is part of the ProteanOS Archive Manager.
#
# The ProteanOS Archive Manager is free software: you can redistribute
# it and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# The ProteanOS Archive Manager is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the ProteanOS Archive Manager.  If not, see
# <http://www.gnu.org/licenses/>.

. ${0%/*}/aux/init.sh
. tap-functions.sh
. opk.sh

plan_ 12

if ${EMBEDDED_USIGN}; then
	usign="${abs_top_builddir}/3rdparty/usign/usign"
else
	usign="${USIGN}"
fi

mkdir 'archive/'
cat >'archive/conf' <<-EOF
	conf_gzip=true
	conf_key=key
	EOF

command_ok_ 'key generation' -- \
	"${usign}" -G -c 'archive signing key' \
	-p 'archive/key.pub' -s 'archive/key'

changes="$(make_opks_and_changes 'foo' 'foo bar' '1.0-1' 'arch' 'plat' 'trunk' \
	'base')"

command_ok_ 'pro-archman include' -- \
	"${PRO_ARCHMAN}" -v -b 'archive/' include "${changes}"

command_ok_ 'verification' -- \
	"${usign}" -V -m 'archive/feeds/dev/trunk/arch/plat/base/Packages' \
	-p 'archive/key.pub' \
	-x 'archive/feeds/dev/trunk/arch/plat/base/Packages.sig'

command_ok_ 'verification of wrong file' -- not \
	"${usign}" -V -m 'archive/feeds/dev/trunk/arch/plat/base/Packages.gz' \
	-p 'archive/key.pub' \
	-x 'archive/feeds/dev/trunk/arch/plat/base/Packages.sig'

mv 'archive/key.pub' 'archive/key.pub.old'
command_ok_ 'key generation' -- \
	"${usign}" -G -c 'archive signing key' \
	-p 'archive/key.pub' -s 'archive/key'

command_ok_ 'verification with wrong key' -- not \
	"${usign}" -V -m 'archive/feeds/dev/trunk/arch/plat/base/Packages' \
	-p 'archive/key.pub' \
	-x 'archive/feeds/dev/trunk/arch/plat/base/Packages.sig'

command_ok_ 'verification with wrong key' -- not \
	"${usign}" -V -m 'archive/feeds/dev/trunk/arch/plat/base/Packages.gz' \
	-p 'archive/key.pub' \
	-x 'archive/feeds/dev/trunk/arch/plat/base/Packages.sig'

command_ok_ 'pro-archman sign' -- \
	"${PRO_ARCHMAN}" -v -b 'archive/' sign

command_ok_ 'verification' -- \
	"${usign}" -V -m 'archive/feeds/dev/trunk/arch/plat/base/Packages' \
	-p 'archive/key.pub' \
	-x 'archive/feeds/dev/trunk/arch/plat/base/Packages.sig'

command_ok_ 'verification of wrong file' -- not \
	"${usign}" -V -m 'archive/feeds/dev/trunk/arch/plat/base/Packages.gz' \
	-p 'archive/key.pub' \
	-x 'archive/feeds/dev/trunk/arch/plat/base/Packages.sig'

command_ok_ 'verification with wrong key' -- not \
	"${usign}" -V -m 'archive/feeds/dev/trunk/arch/plat/base/Packages' \
	-p 'archive/key.pub.old' \
	-x 'archive/feeds/dev/trunk/arch/plat/base/Packages.sig'

command_ok_ 'verification with wrong key' -- not \
	"${usign}" -V -m 'archive/feeds/dev/trunk/arch/plat/base/Packages.gz' \
	-p 'archive/key.pub.old' \
	-x 'archive/feeds/dev/trunk/arch/plat/base/Packages.sig'

:
